.. image:: https://travis-ci.org/tuomas2/serviceform.svg?branch=master
   :target: https://travis-ci.org/tuomas2/serviceform

.. image:: https://coveralls.io/repos/github/tuomas2/serviceform/badge.svg?branch=master
   :target: https://coveralls.io/github/tuomas2/serviceform?branch=master

.. image:: https://img.shields.io/codeclimate/github/tuomas2/serviceform.svg
   :target: https://codeclimate.com/github/tuomas2/serviceform

.. image:: https://www.versioneye.com/user/projects/5922f7e68dcc41003af21f61/badge.svg
   :target: https://www.versioneye.com/user/projects/5922f7e68dcc41003af21f61

.. image:: https://img.shields.io/pypi/v/serviceform.svg
   :target: https://pypi.python.org/pypi/serviceform

.. image:: https://img.shields.io/pypi/pyversions/serviceform.svg
   :target: https://pypi.python.org/pypi/serviceform

.. image:: https://img.shields.io/badge/licence-GPL--3-blue.svg
   :target: https://github.com/tuomas2/serviceform/blob/master/LICENSE.txt


Serviceform
===========

Web application for collecting data from volunteers of willingness to participate.


Documentation
-------------

User / server admin guides:

 - `Production guide with Docker <https://github.com/tuomas2/serviceform/wiki/Production-guide-with-Docker>`_

Developer guides:

 - `General developer guide <https://github.com/tuomas2/serviceform/wiki/Development>`_
 - `Install as Django application to your project <https://github.com/tuomas2/serviceform/wiki/Install-as-Django-application-to-your-project>`_



LICENSE
-------

Copyright (C) 2017 Tuomas Airaksinen

Serviceform is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Serviceform is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Serviceform.  If not, see <http://www.gnu.org/licenses/>.

For more information, `see LICENSE.txt <LICENSE.txt>`_